import json

async def sort_reqarg(KEY, Type="json", pIndex=str(1), pSize=str(100)):
    """
    ``KEY``는 Open APi키를 필요로합니다.

    ``Type``는 json 또는 xml값을 요청할수있습니다. 기본값은 json입니다.

    ``pIndex``는 페이지 위치입니다. 기본값은 1입니다.

    ``pSize``는 페이지 당 신청 숫자입니다. 기본값은 100입니다

    ``str``로 반환됩니다.
    """
    apikey = f"?KEY={KEY}"
    reqtype = f"&Type={Type}"
    pindex = f"&pindex={pIndex}"
    psize = f"&pSize={pSize}"
    return(apikey + reqtype + pindex + psize)

async def sort_lunchmenu(data):
    """
    json형식만 받아옵니다.

    json을 정리하여 급식 메뉴만을 ``str``로 반환합니다.
    """
    result = json.loads(data)
    lunchlist = result['mealServiceDietInfo']
    lunch = lunchlist[1]
    lunchreault  = lunch['row']
    lunchinfo = lunchreault[0]
    flunch = lunchinfo['DDISH_NM']
    linebreak = flunch.replace('<br/>', '\n')
    return linebreak

async def sort_schoolcode(data):
    """
    json형식만 받아옵니다.

    json을 정리하여 시도교육청코드,표준학교코드를 ``tuple``로 반환합니다.
    """
    result = json.loads(data)
    schoollist = result['schoolInfo']
    school = schoollist[1]
    scresult = school['row']
    scinfo = scresult[0]
    SC_CODE = scinfo['ATPT_OFCDC_SC_CODE']
    SD_SCHUL_CODE = scinfo['SD_SCHUL_CODE']
    return(SC_CODE, SD_SCHUL_CODE)




import aiohttp
import datetime

n = datetime.datetime.now()
now = f'{n.year}{n.month}{n.day}'

apimain = "https://open.neis.go.kr/hub/mealServiceDietInfo" #오픈 api요청주소

async def lunchinfo(param, ATPT_OFCDC_SC_CODE, SD_SCHUL_CODE, MLSV_YMD=now):
    """
    ``param``은 필수인자입니다.

    ``ATPT_OFCDC_SC_CODE``은 시도교육청코드 입니다.

    ``SD_SCHUL_CODE``은 표준학교코드 입니다.

    ``MLSV_YMD``은 급식을 불러올 날짜를 지정할수있습니다.

    인자값을 주지않은경우에는 현재날짜로 급식을 불러옵니다.

    요청한 값은 ``str``로 반환됩니다.
    """
    AE = f'&ATPT_OFCDC_SC_CODE={ATPT_OFCDC_SC_CODE}'
    SE = f'&SD_SCHUL_CODE={SD_SCHUL_CODE}'
    MD = f'&MLSV_YMD={MLSV_YMD}'
    async with aiohttp.ClientSession() as cs:
        async with cs.get(apimain + param + AE + SE + MD) as r:
            response = await r.text()
            return response


import setuptools

setuptools.setup(
    name="neispy",
    version="0.1",
    license='MIT',
    author="Ryu ju heon",
    author_email="SaidBySolo@gmail.com",
    description="open-neis-api wrapping with aiohttp",
    long_description=open('README.md', 'rt', encoding='UTF8').read(),
    long_description_content_type="text/markdown",
    url="https://github.com/SaidBySolo/neispy",
    packages=setuptools.find_packages(),
    classifiers=[
        # 패키지에 대한 태그
        "Programming Language :: Python :: 3.8",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
    python_requires='>=3.6'
)


import aiohttp

apimain = "https://open.neis.go.kr/hub/schoolInfo" 
        
async def schoolinfo(param, schoolname):
    """
    ``param``은 필수인자값입니다.

    ``schoolname``은 학교 이름을 받습니다.

    요청한값은 ``str``형식으로 반환합니다.
    """
    schul_nm = f'&SCHUL_NM={schoolname}'
    async with aiohttp.ClientSession() as cs:
        async with cs.get(apimain + param + schul_nm) as r:
            response = await r.text()
            return response


